@@ -1,9 +1,10 @@
 # Copyright 2021 Erfan Abdi
 # SPDX-License-Identifier: GPL-3.0-or-later
-from tools.actions.initializer import init, wait_for_init, remote_init_client
+from tools.actions.initializer import init, remote_init_client
 from tools.actions.upgrader import upgrade
 from tools.actions.session_manager import start, stop
 from tools.actions.container_manager import start, stop, freeze, unfreeze
 from tools.actions.app_manager import install, remove, launch, list
 from tools.actions.status import print_status
 from tools.actions.prop import get, set
+from tools.actions.bugreport import bugreport
