@@ -13,6 +13,7 @@ import queue
 import time
 import dbus
 import dbus.service
+import argparse
 from gi.repository import GLib
 
 def is_initialized(args):
@@ -260,7 +261,12 @@ def remote_init_proc_entry(args, pipe):
     finally:
         pipe.close()
 
-def remote_init_server(args, dbus_obj, params):
+def remote_init_server(_args, dbus_obj, params):
+    args = argparse.Namespace()
+    tools.prep_args(args)
+    args.details_to_stdout = _args.details_to_stdout
+    args.verbose = _args.verbose
+    args.quiet = _args.quiet
     args.force = True
     args.images_path = ""
     args.rom_type = ""
